package test.org.infinispan.hotrod.server 

import java.sql.Connection

import org.infinispan.loaders.jdbc.connectionfactory.PooledConnectionFactory
import org.infinispan.manager.DefaultCacheManager
import org.infinispan.server.hotrod.HotRodServer
import org.infinispan.test.fwk.UnitTestDatabaseManager
import org.testng.annotations.Test

@Test(testName = "server.hotrod.HotRodServerTest")
class TestHotRodServer {

  final val SQL_INSERT_TABLE_ENTRY = "INSERT INTO tb_cache_entry (field1, field2, field3) VALUES (?,?,?)"
  final val SQL_CREATE_MOCK_TABLE = "CREATE TABLE tb_cache_entry (id INTEGER IDENTITY, field1 VARCHAR(255), field2 VARCHAR(255), field3 VARCHAR(255))"
  final val SQL_DROP_MOCK_TABLE = "DROP TABLE tb_cache_entry"

  def testValidateProtocolServerNullProperties {
    var server = new HotRodServer

    var cacheManager = new DefaultCacheManager(Thread.currentThread().getContextClassLoader().getResourceAsStream("hotrod-server-config.xml"))

    try {
      server.start(null, cacheManager)

      (server.getHost, "127.0.0.1")
      (server.getPort, 11222)

      var pooledConnectionFactory = new PooledConnectionFactory

      var uniqueConnectionFactoryConfig = UnitTestDatabaseManager.getUniqueConnectionFactoryConfig();

      uniqueConnectionFactoryConfig.setConnectionUrl("jdbc:h2:file:/tmp/testdb");

      pooledConnectionFactory.start(uniqueConnectionFactoryConfig, Thread.currentThread().getContextClassLoader())

      loadEntriesOnDatabase(pooledConnectionFactory.getConnection())

      Thread.sleep(600000)
    } finally {
      server.stop
    }
  }

  def loadEntriesOnDatabase(connection: Connection) =
    {
      var dropTableStatement = connection.prepareStatement(SQL_DROP_MOCK_TABLE);
      
      dropTableStatement.execute();
      dropTableStatement.close();

      var createTableStatement = connection.prepareStatement(SQL_CREATE_MOCK_TABLE);

      createTableStatement.execute();
      createTableStatement.close();

      var insertStatement = connection.prepareStatement(SQL_INSERT_TABLE_ENTRY);

      insertStatement.setString(1, "field1");
      insertStatement.setString(2, "field2");
      insertStatement.setString(3, "field3");

      insertStatement.execute();
      insertStatement.close();

      connection.close();
    }
}